#
# spec file for package libmediaart
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2013 Dominique Leuenberger, Amsterdam, The Netherlands
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libmediaart
Version:        1.9.7
Release:        1.1
Summary:        Media Art extraction library
# License note: src.rpm contains GPL-2.0+ (tests) and LGPL-2.1+ code
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Productivity/Other
URL:            https://gitlab.gnome.org/GNOME/libmediaart
Source0:        https://download.gnome.org/sources/libmediaart/1.9/%{name}-%{version}.tar.xz

BuildRequires:  gcc-c++
BuildRequires:  gobject-introspection-devel >= 1.30.0
BuildRequires:  gtk-doc
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gdk-pixbuf-2.0) >= 2.12.0
BuildRequires:  pkgconfig(gio-2.0) >= 2.35.1
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.35.1
BuildRequires:  pkgconfig(glib-2.0) >= 2.35.1
BuildRequires:  pkgconfig(vapigen)

%description
The libmediaart library is the foundation for media art caching,
extraction and lookup for applications on the desktop.

%package -n libmediaart-2_0-0
# License note: the library is pure LGPL-2.1+
Summary:        Media Art extraction library
License:        LGPL-2.1-or-later
Group:          System/Libraries

%description -n libmediaart-2_0-0
The libmediaart library is the foundation for media art caching,
extraction and lookup for applications on the desktop.

%package -n typelib-1_0-MediaArt-2_0
# License note: the library is pure LGPL-2.1+
Summary:        Introspection bindings for the Media Art extraction library
License:        LGPL-2.1-or-later
Group:          System/Libraries

%description -n typelib-1_0-MediaArt-2_0
The libmediaart library is the foundation for media art caching,
extraction and lookup for applications on the desktop.

%package devel
# License note: the library is pure LGPL-2.1+
Summary:        Development files for the Media Art extraction library
License:        LGPL-2.1-or-later
Group:          Development/Languages/C and C++
Requires:       libmediaart-2_0-0 = %{version}
Requires:       typelib-1_0-MediaArt-2_0 = %{version}

%description devel
The libmediaart library is the foundation for media art caching,
extraction and lookup for applications on the desktop.

%prep
%autosetup -p1

%build
%meson \
	-Dimage_library=gdk-pixbuf \
	-Dgtk_doc=true \
	%{nil}
%meson_build

%install
%meson_install

%post -n libmediaart-2_0-0 -p /sbin/ldconfig
%postun -n libmediaart-2_0-0 -p /sbin/ldconfig

%files -n libmediaart-2_0-0
%license COPYING.LESSER
%{_libdir}/libmediaart-2.0.so.*

%files -n typelib-1_0-MediaArt-2_0
%{_libdir}/girepository-1.0/MediaArt-2.0.typelib

%files devel
%doc %{_datadir}/gtk-doc/html/%{name}/
%{_datadir}/gir-1.0/MediaArt-2.0.gir
%{_libdir}/libmediaart-2.0.so
%{_libdir}/pkgconfig/libmediaart-2.0.pc
%{_includedir}/libmediaart-2.0/
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/libmediaart-2.0.deps
%{_datadir}/vala/vapi/libmediaart-2.0.vapi

%changelog
* Sun Mar  2 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.9.7:
  + Fix memory leaks and compiler warnings.
* Wed Jun  1 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.9.6:
  + build: Add introspection/vapi/tests options.
  + build: Use library() to optionally build a static library.
* Sat May 22 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.9.5:
  + libmediaart:
  - Remove QT4 support
  - Mandate that input strings are UTF8
  + extract: Remove local storage
  + build:
  - Drop autotools support
  - Update to recent glib API
  - Introspection fixes
  - Added CI
- Drop meson-Introspection-fix.patch: Fixed upstream.
- Update meson option for building docs to new gtk_doc=true value.
* Wed Mar 11 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Fix URL, update to current home.
- Use autosetup macro.
* Mon Mar  5 2018 jengelh@inai.de
- Update summaries.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Fri Jan 12 2018 robert.munteanu@gmail.com
- Add meson-Introspection-fix.patch: The meson build did not add
  the extractdummy.c to the sources, which contains introspection
  annotations (bgo#792272, bgo#791586).
* Tue Aug 22 2017 zaitor@opensuse.org
- Add meson BuildRequires and switch autotools macros configure,
  make and makeinstall to meson, meson_build and meson_install
  following upstream switch to Meson build system.
- Add pkgconfig(vapigen) BuildRequires: Build Vala bindings.
- Run spec-cleaner, modernize spec, add pkgconfig BuildRequires.
* Mon Aug 14 2017 zaitor@opensuse.org
- Update to version 1.9.4:
  + Brown paper bag release, export some missing methods that went
    unintentionally hidden.
- Changes from version 1.9.3:
  + Brown paper bag release, fixes soname on meson builds and
    missing includes on autotools.
- Changes from version 1.9.2:
  + extract: Remove Nokia album art downloader support.
  + build:
  - Improve dependency tracker for marshallers sources.
  - Remove duplicate introspection comment for
    media_art_error_quark().
  - Add meson build instructions.
- Drop upstream fixed patches:
  + libmediaart-remove-nokia-albumart.patch.
  + libmediaart-build-marshall-files-fixes.patch.
  + libmediaart-remove-duplicate-introspection.patch.
- Drop libtool BuildRequires and stop passsing autoreconf, no
  longer needed as there are no more patches.
* Fri Jul 28 2017 zaitor@opensuse.org
- Add libmediaart-remove-nokia-albumart.patch: Remove Nokia album
  art downloader support (bgo#767959).
- Add libmediaart-build-marshall-files-fixes.patch: Improve
  dependency tracking for marshallers sources and add an explicit
  dependency on marshal files.
- Add libmediaart-remove-duplicate-introspection.patch: Remove
  duplicate introspection comment for media_art_error_quark().
- Add libtool BuildRequires and pass autoreconf as one of the
  patches touches the buildsystem.
* Mon Mar  6 2017 zaitor@opensuse.org
- Update to version 1.9.1:
  + Extract:
  - Introspection fix.
  - Coverity fix.
  + tests: Fix tests to run both installed and built.
  + libmediaart: Fix marshallers, hide private symbols.
* Sat Jan 28 2017 zaitor@opensuse.org
- Pass --disable-static, --enable-gdkpixbuf, --enable-gtk-doc,
  - -disable-qt and --disable-installed-tests to configure, ensure
  we build the options we want.
- Following the above, add gtk-doc BuildRequires.
* Wed Dec 17 2014 zaitor@opensuse.org
- Update to version 1.9.0:
  + tracker should not scatter .mediaartlocal folders across
    filesystem (bgo#722795).
  + Add async calls (bgo#724879).
- Bump soname, and rename subpackages following upstream changes.
* Mon Sep 22 2014 zaitor@opensuse.org
- Update to version 0.7.0:
  + Fixes:
  - Artist, title and prefix arguments in get_file should
    (bgo#727478).
  - make check clears user's media-art cache (bgo#731681).
  + extract: Fixed gtkdoc warning for return value of
    media_art_error_quark().
* Tue Aug 19 2014 dimstar@opensuse.org
- Update to version 0.6.0:
  + Fixes: media_art_get_path() usage is unclear (bgo#734837).
  + build: include m4 dir parsing.
  + tests: Use tap automake testing scripts, fixes output
    summaries.
  + doap: add <programming-language> and 'core' category.
  + extract: Fixed process_buffer() len check (was inverted) and
    artist/title.
- Changes from version 0.5.0:
  + Heuristics does not handle uppercase properly (bgo#731678).
  + Build system:
  - Require glib 2.38 for g_assert_true() in unit tests.
  - Updated configure.ac from autoscan suggestions.
  - Improve warnings used when compiling and test compiler
    warnings we can use.
  + extract:
  - Switch to initable MediaArtProcess object from
    _init/_shutdown().
  - Split _process() API into  _process_buffer() and
    _process_file().
  - Make GFile first parameter for _process_file().
  - Add _SYMLINK_FAILED error and report symlink() failure in
    get_heuristic().
  - Add GError for _NO_TITLE, which is required in some cases.
  - Add GError * reporting right down to the plugins (pixbuf/qt).
  - Use a more logical ordered heuristic for caching strings.
  - Refactor media_art_process_file() to simplify the function.
  + storage: Make g_message() calls g_debug() calls, output is
    unnecessary.
  + docs: Fixed Makefile so we don't fail on distcheck with
  - -enable-gtk-doc.
  + tests:
  - Don't expect media art extraction for NULL data buffer for
    !images.
  - Test for no error with media_art_process_file() with real use
    case.
* Tue Apr  1 2014 zaitor@opensuse.org
- Update to version 0.4.0:
  + Feature request: load album art embedded in music files
    (bgo#727333).
  + build: Don't forget to define LIBMEDIAART_BACKEND for all Qt
    cases.
  + extract: Incorrect inverse variable check for media_art_set().
* Fri Mar  7 2014 dimstar@opensuse.org
- Update to version 0.3.0:
  + build: Don't fail if vapigen isn't available.
  + build: Force automake C linkage when building C only.
  + build: Remove leftover explicit -lm -lz linkage.
  + build: Don't link to both Qt and gdk-pixbuf if both are
    autodetect.
  + build: Honor NOCONFIGURE=1 in autogen.sh.
  + cache: Improve _remove() function and fix crash with NULL
    passed.
  + cache: Improve _strip_invalid_entites() API.
  + cache: Fix Non-void function should return a value.
  + extract: Fix Qt5 compilation failure
  + extract: Don't break on dummy implementation due to incorrect
    args in.
* Thu Feb  6 2014 dimstar@opensuse.org
- Update to version 0.2.0:
  + build: Remove all 'tracker' uses in configure.ac.
  + build: Fix selection between backends Qt and GdkPixbuf.
  + build: Fix requirement on tracker-0.16 in pkgconfig file.
  + build: Make sure pkgconfig file uses -1.0 to avoid minor ver
    changes.
  + extract: Port Qt backend to Qt5 and NEMO platform.
  + extract: Fixed Qt(4) backend to compile and removed all Tracker
    references.
  + libmediaart: Fix include which incorrectly defined _INSIDE in
    main header.
  + docs: Remove reference to Tracker in reference overview.
- Rename subpackage, following upstreams name changes:
  + libmediaart-0_2-0 to libmediaart-1_0-0.
  + typelib-1-0-MediaArt-0_2 to typelib-1-0-MediaArt-1_0.
* Wed Dec 18 2013 dimstar@opensuse.org
- Initial package, version 0.1.0:
  + The code for this project has been extracted from Tracker and
    inserted into its own library because there is call for this
    functionality in other places on the desktop.
